@@ -16,9 +16,9 @@
 
 #' mirai: Minimalist Async Evaluation Framework for R
 #'
-#' Extremely simple and lightweight method for concurrent / parallel code
-#'     execution, built on 'nanonext' and 'NNG' (Nanomsg Next Gen) technology.
-#'     mirai is Japanese for 'future'.
+#' Simple and lightweight parallelism and concurrent code execution, local or
+#'     distributed across the network, built on 'nanonext' and 'NNG' (Nanomsg
+#'     Next Gen) technology. mirai is Japanese for 'future'.
 #'
 #' @section Links:
 #'
@@ -43,16 +43,23 @@
 NULL
 
 .onLoad <- function(libname, pkgname) {
-  daemons <- daemons()
-  daemons <<- daemons
+  daemons <<- daemons()
 }
 
 .onUnload <- function(libpath) {
   invisible(daemons(0L))
 }
 
+.miraiclass <- c("mirai", "recvAio")
+.errorclass <- c("miraiError", "errorValue")
 .sysname <- .subset2(Sys.info(), "sysname")
-
+.command <- switch(.sysname,
+                   Windows = file.path(R.home("bin"), "Rscript.exe"),
+                   file.path(R.home("bin"), "Rscript"))
+.urlfmt <- switch(.sysname,
+                  Linux = "abstract://n%.f",
+                  Windows = "ipc://n%.f",
+                  "ipc:///tmp/n%.f")
 .__scm__. <- as.raw(c(0x58, 0x0a, 0x00, 0x00, 0x00, 0x03, 0x00, 0x04, 0x02,
                       0x01, 0x00, 0x03, 0x05, 0x00, 0x00, 0x00, 0x00, 0x05,
                       0x55, 0x54, 0x46, 0x2d, 0x38, 0x00, 0x00, 0x00, 0xfc))
